@@ -1,15 +1,15 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "elpy" "1.35.0"
+(define-package "elpy" "20250404.2349"
   "Emacs Python Development Environment."
-  '((company               "0.9.2")
+  '((company               "0.9.10")
     (emacs                 "24.4")
-    (highlight-indentation "0.5.0")
-    (pyvenv                "1.3")
-    (yasnippet             "0.8.0")
-    (s                     "1.11.0"))
+    (highlight-indentation "0.7.0")
+    (pyvenv                "1.20")
+    (yasnippet             "0.13.0")
+    (s                     "1.12.0"))
   :url "https://github.com/jorgenschaefer/elpy"
-  :commit "4666c16ef362d4f99053bbc0856d8c65121e1825"
-  :revdesc "1.35.0-0-g4666c16ef362"
+  :commit "0b381f55969438ab2ccc2d1a1614045fcf7c9545"
+  :revdesc "0b381f559694"
   :keywords '("python" "ide" "languages" "tools")
   :authors '(("Jorgen Schaefer" . "contact@jorgenschaefer.de")
              ("Gaby Launay" . "gaby.launay@protonmail.com"))
